@@ -297,66 +297,77 @@ checkVigTemplate <- function(vigdircontents)
 detect_non_eval_chunks <- function(lines, vignetteType) {
     non_eval_pattern <- switch(
         vignetteType,
-        qmd = ,
+        qmd = "^[\t >]*```+\\{\\{r\\s*\\w*\\}\\}$",
         rmd = "^[\t >]*```+\\s*$",
         rnw = "\\\\begin\\{verbatim\\}",
-        rhtml = "^<!--\\s*begin\\.rcode.*eval\\s*=\\s*F(ALSE)?"
-    )
-    chunk_patterns_start <- switch(
-        vignetteType,
-        qmd = "^```\\{r\\}",
-        rmd = knitr::all_patterns[["md"]]$chunk.begin,
-        rnw = knitr::all_patterns[["rnw"]]$chunk.begin,
-        rhtml = "^<!--\\s*begin\\.rcode"
+        rhtml = "$.^"
     )
+    non_eval_chunk_lines <- grep(non_eval_pattern, lines)
     chunk_patterns_end <- switch(
         vignetteType,
         qmd = ,
         rmd = knitr::all_patterns[["md"]]$chunk.end,
         rnw = knitr::all_patterns[["rnw"]]$chunk.end,
-        rhtml = "^end\\.rcode\\s*-->"
+        rhtml = knitr::all_patterns[["html"]]$chunk.end
     )
-
-    chunk_starts <- grep(chunk_patterns_start, lines)
-    ## find all potential chunk ends
     chunk_ends <- grep(chunk_patterns_end, lines)
 
-    non_eval_chunk_lines <- grep(non_eval_pattern, lines)
-
-    if (vignetteType %in% c("rmd", "qmd")) {
-        matched_chunk_ends <- integer(0L)
-        irregular_non_eval_chunks <- integer(0L)
-        for (i in seq_along(chunk_starts)) {
-            # Find the next end marker after this start
-            next_end_index <- which(chunk_ends > chunk_starts[i])[1L]
-
-            if (!is.na(next_end_index)) {
-                matched_chunk_ends <-
-                    c(matched_chunk_ends, chunk_ends[next_end_index])
-                # Remove this end from further consideration
+    if (!identical(vignetteType, "rmd")) {
+        for (i in seq_along(non_eval_chunk_lines)) {
+            next_end_index <-
+                which(chunk_ends > non_eval_chunk_lines[i])[1L]
+            if (!is.na(next_end_index))
                 chunk_ends <- chunk_ends[-next_end_index]
-            }
         }
-        irregular_non_eval_chunks <- chunk_ends
-    } else if (vignetteType %in% c("rnw", "rhtml")) {
-        irregular_non_eval_chunks <- grep(non_eval_pattern, lines)
-    } else {
-        stop("Unknown vignette type: ", vignetteType)
     }
 
-    eval_false_lines <- grep("eval\\s*=\\s*F(ALSE)?", lines[chunk_starts])
+    chunk_patterns_start <- switch(
+        vignetteType,
+        qmd =  "^[\t >]*```+\\s*\\{r",
+        rmd = knitr::all_patterns[["md"]]$chunk.begin,
+        rnw = knitr::all_patterns[["rnw"]]$chunk.begin,
+        rhtml = knitr::all_patterns[["html"]]$chunk.begin
+    )
+    chunk_starts <- setdiff(
+        grep(chunk_patterns_start, lines), non_eval_chunk_lines
+    )
+
+    for (i in seq_along(chunk_starts)) {
+        next_end_index <- which(chunk_ends > chunk_starts[i])[1L]
+        if (!is.na(next_end_index)) {
+            if (identical(vignetteType, "rmd"))
+                non_eval_chunk_lines <- non_eval_chunk_lines[
+                    non_eval_chunk_lines != chunk_ends[next_end_index]
+                ]
+            chunk_ends <- chunk_ends[-next_end_index]
+        }
+    }
+    if (length(chunk_ends) && identical(vignetteType, "rmd"))
+        non_eval_chunk_lines <- chunk_ends[c(TRUE, FALSE)]
+
+    eval_false_lines <- 0L
+    if (identical(vignetteType, "qmd"))
+        eval_false_lines <- grep("#\\|\\s*eval\\s*:\\s*F(ALSE)?", lines, TRUE)
+    else
+        eval_false_lines <- grep(
+            "eval\\s*=\\s*F(ALSE)?", lines[chunk_starts], TRUE
+        )
 
     list(
-        chunks = length(chunk_starts) + length(irregular_non_eval_chunks),
-        efs = length(eval_false_lines),
-        noneval = length(irregular_non_eval_chunks)
-    )
+        total = c(length(chunk_starts), length(non_eval_chunk_lines)),
+        eval_false = length(eval_false_lines),
+        non_eval = length(non_eval_chunk_lines)
+    ) |>
+        lapply(
+            function(values)
+                as.integer(sum(values))
+        )
 }
 
-.EVAL_CHUNKS_SENTINEL <- list(
-    chunks = 0L,
-    efs = 0L,
-    noneval = 0L
+.CHUNKS_SENTINEL <- list(
+    total = 0L,
+    eval_false = 0L,
+    non_eval = 0L
 )
 
 checkVigChunkEval <- function(vigdircontents)
@@ -367,7 +378,7 @@ checkVigChunkEval <- function(vigdircontents)
             lines <- readLines(file, warn=FALSE)
             vigExt <- tolower(tools::file_ext(file))
             if (!vigExt %in% c("rmd", "qmd", "rnw", "rhtml"))
-                .EVAL_CHUNKS_SENTINEL
+                .CHUNKS_SENTINEL
             else
                 detect_non_eval_chunks(lines, vigExt)
         }
@@ -376,26 +387,28 @@ checkVigChunkEval <- function(vigdircontents)
     combined <- Reduce(
         function(x, y) {
             list(
-                chunks = x$chunks + y$chunks,
-                efs = x$efs + y$efs,
-                noneval = x$noneval + y$noneval
+                total = x$total + y$total,
+                eval_false = x$eval_false + y$eval_false,
+                non_eval = x$non_eval + y$non_eval
             )
-        }, results, init = .EVAL_CHUNKS_SENTINEL
+        },
+        results,
+        init = .CHUNKS_SENTINEL
     )
 
-    totnon <- combined$efs + combined$noneval
+    totnon <- combined$eval_false + combined$non_eval
     percent <-
-        if (!combined$chunks && !totnon)
+        if (!combined$total && !totnon)
             0L
         else
-            as.integer((totnon * 100 / combined$chunks))
+            as.integer((totnon * 100 / combined$total))
 
     if (percent >= 50) {
         handleWarning("Evaluate more vignette chunks.")
         msg <- sprintf(
             "%s out of %s code chunks = %i%% unevaluated",
             totnon,
-            combined$chunks,
+            combined$total,
             percent
         )
         handleMessage(msg, indent = 8)
